package xyz.thastertyn.Jecna;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import xyz.thastertyn.Tuple.Pair;

public class Znamky {

	private boolean wasDownloaded;

	// key (String) reprezentuje predmet, value (arraylist) znamky a pair znamku s jeji vahou
	private HashMap<String, ArrayList<Pair<Integer, Double>>> grades = new HashMap<>();

	public void addGrade(String subject, int grade, double weight)
	{
		grades.get(subject).add(new Pair<Integer,Double>(grade, weight));
	}

	public void addSubject(String subject)
	{
		grades.put(subject, new ArrayList<Pair<Integer, Double>>());
	}

	private double getAverage(ArrayList<Pair<Integer, Double>> a)
	{
		try{
			int divident = 0;
			int divisor = 0;
			for(Pair<Integer, Double> p : a)
			{
				divident += p.getValue0() * p.getValue1();
				divisor += p.getValue1();
			}

			return (double) divident / divisor;

		}catch(ArithmeticException e)
		{
			return 0;
		}
	}

	public byte downloadZnamky(final String Jsessionid)
	{
		wasDownloaded = true;
		Document znamkyDoc = null;

		try {
			znamkyDoc = Downloader.download("https://www.spsejecna.cz" + "/score/student", Jsessionid).get();
		} catch (IOException e) {
			e.printStackTrace();
			return 127;
		}
		
		Elements rows = znamkyDoc.select("table.score").select("tr");

		Elements[] rows_split = new Elements[rows.size()];

		for (int i = 0; i < rows.size(); i++)
		{
			rows_split[i] = rows.get(i).children();
		}

		for(int i = 1; i < rows_split.length; i++)
		{
			String predmet = rows_split[i].get(0).text();
			addSubject(predmet);
			
			for(Element e : rows_split[i].get(1).select("a.score"))
			{
				int znamka = Integer.parseInt(e.select("span.value").text());

				// Mala znamka se bude pocitat jako polovicni vaha
				if(e.hasClass("scoreSmall"))
				{
					addGrade(predmet, znamka, 0.5);
				}else{
					addGrade(predmet, znamka, 1);
				}
			}
		}
		return 0;
	}

	@Override
	public String toString()
	{
		if(wasDownloaded)
		{
			String s = "";
	
			for(Map.Entry<String, ArrayList<Pair<Integer, Double>>> entry : grades.entrySet())
			{
				double prumer = getAverage(entry.getValue());
				double p = (double) Math.round(prumer * 100) / 100;
				s += entry.getKey() + " | " + entry.getValue().toString() + " { " + p + " }\n";
			}
			return s;
		}else{
			return "Nothing was downloaded";
		}

	}
}